@@ -26,7 +26,7 @@ const KEY_BINDINGS: &[(&[&str], &str)] = &[
 /// Renders the user interface widgets.
 pub fn render(app: &mut App, frame: &mut Frame) {
     let rects =
-        Layout::vertical([Constraint::Min(1), Constraint::Percentage(100)]).split(frame.size());
+        Layout::vertical([Constraint::Min(1), Constraint::Percentage(100)]).split(frame.area());
     render_header(app, frame, rects[0]);
     render_list(app, frame, rects[1]);
     render_cursor(app, frame, rects[1]);
@@ -39,26 +39,28 @@ fn render_list(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
     let page = selected_index / TABLE_PAGE_LIMIT;
     let mut table_state = TableState::default();
     table_state.select(Some(selected_index % TABLE_PAGE_LIMIT));
-    let items = app
+    let mut items = Vec::new();
+    for cve in app
         .list
         .items
         .iter()
         .skip(page * TABLE_PAGE_LIMIT)
         .take(TABLE_PAGE_LIMIT)
-        .map(|cve| {
-            let description = match &cve.description {
+    {
+        let description = highlight_search_result(
+            match &cve.description {
                 Some(v) => textwrap::wrap(
                     v,
                     textwrap::Options::new(area.width.saturating_sub(15) as usize),
                 )
                 .join("\n"),
                 None => "No description available.".into(),
-            };
-            Row::new(vec![cve.id.to_string(), description])
-                .height(2)
-                .top_margin(1)
-        })
-        .collect::<Vec<Row>>();
+            },
+            app,
+        );
+        let cve_id = highlight_search_result(cve.id.to_string(), app);
+        items.push(Row::new(vec![cve_id, description]).height(2).top_margin(1))
+    }
     let block = Block::bordered()
         .style(if app.show_details {
             app.theme.dim
@@ -121,7 +123,7 @@ fn render_list(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
                 "Description".set_style(app.theme.highlight).bold(),
             ]))
             .block(block)
-            .highlight_style(app.theme.selected.bold()),
+            .row_highlight_style(app.theme.selected.bold()),
         area,
         &mut table_state,
     );
@@ -130,7 +132,7 @@ fn render_list(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
             .style(app.theme.scrollbar)
             .begin_symbol(Some("↑"))
             .end_symbol(Some("↓")),
-        area.inner(&Margin {
+        area.inner(Margin {
             vertical: 1,
             horizontal: 0,
         }),
@@ -138,6 +140,19 @@ fn render_list(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
     );
 }
 
+fn highlight_search_result(value: String, app: &App) -> Line {
+    if value.contains(app.input.value()) {
+        let splits = value.split(app.input.value());
+        let chunks = splits.into_iter().map(|c| Span::from(c.to_owned()));
+        let pattern = Span::styled(app.input.value(), app.theme.selected);
+        itertools::intersperse(chunks, pattern)
+            .collect::<Vec<Span>>()
+            .into()
+    } else {
+        Line::from(value)
+    }
+}
+
 fn render_header(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
     let title = Paragraph::new(
         format!(
@@ -177,7 +192,7 @@ fn render_cursor(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
                 height: 1,
             },
         );
-        frame.set_cursor(x, y);
+        frame.set_cursor_position((x, y));
     }
 }
 
@@ -245,6 +260,10 @@ fn render_details(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
         if lines.len() > area.height.saturating_sub(2) as usize {
             lines = lines.into_iter().skip(app.scroll_index).collect();
         }
+        for line in lines.iter_mut() {
+            *line = highlight_search_result(line.to_string(), app);
+        }
+        let max_line_width = lines.iter().map(|v| v.width()).max().unwrap_or_default() as u16;
         let height = lines.len();
         let paragraph = Paragraph::new(lines.clone());
         let sized_paragraph = SizedWrapper {
@@ -252,15 +271,13 @@ fn render_details(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
             width: lines.iter().map(|v| v.width()).max().unwrap_or_default(),
             height,
         };
-        let popup = Popup::new(
-            vec![
+        let popup = Popup::new(sized_paragraph)
+            .title(vec![
                 "|".set_style(app.theme.separator),
                 cve.id.to_string().set_style(app.theme.highlight).bold(),
                 "|".set_style(app.theme.separator),
-            ],
-            sized_paragraph,
-        )
-        .style(app.theme.background);
+            ])
+            .style(app.theme.background);
         frame.render_widget(&popup, area);
         app.scroll_details = height > area.height.saturating_sub(2) as usize;
         if app.scroll_details {
@@ -269,13 +286,11 @@ fn render_details(app: &mut App, frame: &mut Frame<'_>, area: Rect) {
                     .style(app.theme.scrollbar)
                     .begin_symbol(Some("↑"))
                     .end_symbol(Some("↓")),
-                area.inner(&Margin {
+                area.inner(Margin {
                     vertical: 1,
-                    horizontal: (area.width.saturating_sub(
-                        lines.iter().map(|v| v.width()).max().unwrap_or_default() as u16,
-                    ) / 2),
+                    horizontal: (area.width.saturating_sub(max_line_width) / 2),
                 }),
-                &mut ScrollbarState::new(lines.len().saturating_sub(area.height as usize) + 2)
+                &mut ScrollbarState::new(height.saturating_sub(area.height as usize) + 2)
                     .position(app.scroll_index),
             );
         }
